import numpy as np
import matplotlib.pyplot as plt
from plot_network import build_pos, plot_network

# Interaction matrix
A = np.array([[ 1, 1, 1],
              [-1,-1,-1],
              [ 1,-1, 1]])

# Node positions and names
pos = build_pos(A)
names = [f'G{i+1}' for i in range(A[0].size)]

# Figure
fig = plt.figure(figsize=(5,5))
ax = fig.gca()

# Draw the network
plot_network(A, pos, axes=ax, names=names, scale=2)

# Export the figure
fig.savefig('network.pdf', bbox_inches='tight')



from setuptools import setup, find_packages
import grnviz

setup(

    name='grnviz',
 
    version=grnviz.__version__,
 
    packages=find_packages(),
 
    author='Ulysse Herbach',
 
    author_email='ulysse.herbach@inria.fr',
 
    # description=('Filtering Lengthwise Using Forest Fields'),
 
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',

    install_requires=['numpy'],
 
    # url='https://github.com/ulysseherbach/harissa',

    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        # 'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
    ],

    platforms='any',

    # license='BSD-3-Clause',
    # license_file='LICENSE.txt',

    # keywords=('stochastic gene expression, gene regulatory networks, '
    #     'single-cell transcriptomics'),
)
